@@ -46,7 +46,6 @@ static string GetWin32Error()
 {
     char *lpMsgBuf;
     DWORD dw = GetLastError();
-    cerr << dw << endl;
     FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER |
                   FORMAT_MESSAGE_FROM_SYSTEM |
                   FORMAT_MESSAGE_IGNORE_INSERTS,
@@ -111,8 +110,24 @@ wchar_t *_wcstok(wchar_t *wcs, const wchar_t *delim, wchar_t **ptr)
 wstring convertToWc(const string& iStr)
 {
 #ifdef WIN32
-    // XXX: Assume the input is in UTF-8
-    return readFromUTF8(iStr.c_str(), iStr.size(), "convertToWc");
+    if (iStr.empty())
+        return L"";
+
+    const unsigned int bufSize = iStr.size();
+    // Temporary buffer for output
+    // We will have at most as many characters as in the UTF-8 string
+    wchar_t *wideBuf = new wchar_t[bufSize];
+    int number = MultiByteToWideChar(CP_OEMCP, MB_ERR_INVALID_CHARS,
+                                     iStr.c_str(), bufSize, wideBuf, bufSize);
+    wstring res(wideBuf, number);
+    delete[] wideBuf;
+    if (number == 0)
+    {
+        // Retrieve the system error message for the last-error code
+        throw DicException("convertToWc: MultiByteToWideChar failed:" +
+                           GetWin32Error());
+    }
+    return res;
 #else
     // Get the needed length (we _can't_ use string::size())
     size_t len = mbstowcs(NULL, iStr.c_str(), 0);
@@ -146,9 +161,15 @@ string convertToMb(const wstring& iWStr)
     if (size == 0)
         return "";
     char buf[size];
-    // XXX: Assume the output is in UTF-8
-    int nb = writeInUTF8(iWStr, buf, size, "convertToMb");
-    return string(buf, nb);
+    int res = WideCharToMultiByte(CP_OEMCP, 0, iWStr.c_str(), iWStr.size(),
+                                  buf, size, NULL, NULL);
+    if (res == 0)
+    {
+        // Retrieve the system error message for the last-error code
+        throw DicException("convertToMb: WideCharToMultiByte failed: " +
+                           GetWin32Error());
+    }
+    return string(buf, res);
 #else
     // Get the needed length (we _can't_ use wstring::size())
     size_t len = wcstombs(NULL, iWStr.c_str(), 0);
@@ -202,10 +223,12 @@ string truncAndConvert(const wstring &iWstr, unsigned int iMaxWidth)
         if (n == -1)
         {
             ostringstream ss;
-            ss << "truncAndConvert: non printable character: " << iWstr[pos];
             // XXX: Should we throw an exception instead? Just ignore the problem?
+#if 0
+            ss << "truncAndConvert: non printable character: " << iWstr[pos];
             cerr << ss.str() << endl;;
             //throw DicException(ss.str());
+#endif
             return convertToMb(iWstr);
         }
         if (width + n > iMaxWidth)
@@ -228,10 +251,12 @@ string truncOrPad(const string &iStr, unsigned int iWidth, char iChar)
         if (n == -1)
         {
             ostringstream ss;
-            ss << "truncAndConvert: non printable character: " << wstr[pos];
             // XXX: Should we throw an exception instead? Just ignore the problem?
+#if 0
+            ss << "truncAndConvert: non printable character: " << wstr[pos];
             cerr << ss.str() << endl;;
             //throw DicException(ss.str());
+#endif
             return convertToMb(wstr);
         }
         if (width + n > iWidth)
@@ -256,10 +281,12 @@ string padAndConvert(const wstring &iWstr, unsigned int iLength,
         if (n == -1)
         {
             ostringstream ss;
-            ss << "padAndConvert: non printable character: " << iWstr[i];
             // XXX: Should we throw an exception instead? Just ignore the problem?
+#if 0
+            ss << "padAndConvert: non printable character: " << iWstr[i];
             cerr << ss.str() << endl;;
             //throw DicException(ss.str());
+#endif
             return convertToMb(iWstr);
         }
         width += n;
@@ -288,10 +315,12 @@ string centerAndConvert(const wstring &iWstr, unsigned int iLength, char c)
         if (n == -1)
         {
             ostringstream ss;
-            ss << "padAndConvert: non printable character: " << iWstr[i];
             // XXX: Should we throw an exception instead? Just ignore the problem?
+#if 0
+            ss << "padAndConvert: non printable character: " << iWstr[i];
             cerr << ss.str() << endl;;
             //throw DicException(ss.str());
+#endif
             return convertToMb(iWstr);
         }
         width += n;
@@ -325,6 +354,10 @@ unsigned int readFromUTF8(wchar_t *oString, unsigned int iWideSize,
                           const string &iContext)
 {
 #ifdef WIN32
+    if (iBuffer == NULL || *iBuffer == '\0')
+    {
+        return 0;
+    }
     int res = MultiByteToWideChar(CP_UTF8, MB_ERR_INVALID_CHARS, iBuffer,
                                   iBufSize, oString, iWideSize);
     if (res == 0)
@@ -385,12 +418,15 @@ unsigned int writeInUTF8(const wstring &iWString, char *oBuffer,
                          unsigned int iBufSize, const string &iContext)
 {
 #ifdef WIN32
+    if (iWString.empty())
+    {
+        *oBuffer = '\0';
+        return 0;
+    }
     int res = WideCharToMultiByte(CP_UTF8, 0, iWString.c_str(), iWString.size(),
                                   oBuffer, iBufSize, NULL, NULL);
     if (res == 0)
     {
-        DWORD dw = GetLastError();
-        cerr << dw << endl;
         // Retrieve the system error message for the last-error code
         throw DicException("writeInUTF8: WideCharToMultiByte failed (" +
                            iContext + "): " + GetWin32Error());
@@ -422,3 +458,27 @@ unsigned int writeInUTF8(const wstring &iWString, char *oBuffer,
 #endif
 }
 
+
+string writeInUTF8(const wstring &iWString, const string &iContext)
+{
+    // Temporary buffer for output
+    // Each character will take at most 4 bytes in the UTF-8 string
+    unsigned int bufSize = iWString.size() * 4;
+    char *buf = new char[bufSize];
+    unsigned int number;
+    try
+    {
+        number = writeInUTF8(iWString, buf, bufSize, iContext);
+    }
+    catch (...)
+    {
+        // Make sure not to leak
+        delete[] buf;
+        throw;
+    }
+    // Copy the string
+    string res(buf, number);
+    delete[] buf;
+    return res;
+}
+
