@@ -1,17 +1,17 @@
 /****************************************************************************
 ** Meta object code from reading C++ file 'bag_widget.h'
 **
-** Created: Sat Sep 26 11:18:29 2009
-**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.1)
+** Created: Fri Jan 1 10:33:19 2010
+**      by: The Qt Meta Object Compiler version 61 (Qt 4.5.2)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
 
-#include "bag_widget.h"
+#include "../../qt/bag_widget.h"
 #if !defined(Q_MOC_OUTPUT_REVISION)
 #error "The header file 'bag_widget.h' doesn't include <QObject>."
 #elif Q_MOC_OUTPUT_REVISION != 61
-#error "This file was generated using the moc from 4.5.1. It"
+#error "This file was generated using the moc from 4.5.2. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
